Name:            monotone
Version:         1.0
Release:         7%{?dist}
Summary:         A free, distributed version control system
Group:           Development/Tools
License:         GPLv2+
URL:             http://monotone.ca/
Source0:         http://monotone.ca/downloads/%{version}/%{name}-%{version}.tar.bz2
Source1:         monotone.init
Source2:         monotone.sysconfig
Source3:         README.monotone-server
Source4:         monotone-server-tmpfiles.conf
# rev da62cad1 from upstream
Patch0:          monotone-1.0-file_handle.patch
# rev a570769b from upstream
Patch1:          monotone-1.0-fix-help.patch
# FTBFS (symbol conflict with boost)
# https://code.monotone.ca/p/monotone/issues/191/
Patch2:          monotone-1.0-disable-xdelta-test.patch
# Fix a failing test with pcre >= 8.21
Patch3:          monotone-1.0-pcre.patch
BuildRoot:       %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:   zlib-devel
BuildRequires:   boost-devel >= 1.33.1
BuildRequires:   botan-devel >= 1.6.3
BuildRequires:   pcre-devel >= 7.4
BuildRequires:   sqlite-devel >= 3.3.8
BuildRequires:   lua-devel >= 5.1
BuildRequires:   libidn-devel
# Required by the test suite:
BuildRequires:   cvs
BuildRequires:   bash-completion
Requires(post):  /sbin/install-info
Requires(preun): /sbin/install-info

# Filter unwanted dependencies
%{?perl_default_filter}

%description
monotone is a free, distributed version control system.
It provides fully disconnected operation, manages complete
tree versions, keeps its state in a local transactional
database, supports overlapping branches and extensible
metadata, exchanges work over plain network protocols,
performs history-sensitive merging, and delegates trust
functions to client-side RSA certificates.


%package server
Summary: Standalone server setup for monotone
Requires: monotone = %{version}-%{release}
Requires(pre): shadow-utils
Requires(post): chkconfig
Requires(preun): initscripts, chkconfig
Requires(postun): initscripts
Group: Development/Tools


%description server
This package provides an easy-to-use standalone server setup for monotone.


%package -n perl-Monotone
Summary: Perl Module for monotone
Requires: monotone = %{version}-%{release}
Requires: perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Group: Development/Tools


%description -n perl-Monotone
This is a simple Perl module to start a monotone automate sub-process
and then pass commands to it.


%prep
%setup -q
%patch0 -p0
%patch1 -p0
%patch2 -p1
%patch3 -p1


%build
export LC_MESSAGES=en_US
%configure
make %{?_smp_mflags}


%check
export DISABLE_NETWORK_TESTS=1
make %{?_smp_mflags} check || { head -n-0 test/work/*.log; false; }


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
rm -f %{buildroot}%{_infodir}/dir
mv %{buildroot}%{_datadir}/doc/%{name} _doc

%find_lang %{name}

mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_localstatedir}/lib
ln -snf ../bin/mtn %{buildroot}%{_sbindir}/monotone-server
ln -snf mtn.1 %{buildroot}%{_mandir}/man1/monotone-server.1
install -D -m 0755 -p %{SOURCE1} \
             %{buildroot}%{_sysconfdir}/rc.d/init.d/monotone
install -D -m 0644 -p %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/monotone
install -d -m 0755 %{buildroot}%{_sysconfdir}/monotone
install -d -m 0750 %{buildroot}%{_sysconfdir}/monotone/private-keys
install -d -m 0770 %{buildroot}%{_localstatedir}/lib/monotone
install -d -m 0755 %{buildroot}%{_localstatedir}/run/monotone
%if 0%{?fedora} >= 15
install -D -m 0644 %{SOURCE4} \
             %{buildroot}%{_sysconfdir}/tmpfiles.d/monotone.conf
%endif

# These do not actually wind up in the package, due to %%ghost.
install -m 0440 /dev/null \
             %{buildroot}%{_sysconfdir}/monotone/passphrase.lua
install -m 0640 /dev/null \
             %{buildroot}%{_sysconfdir}/monotone/read-permissions
install -m 0640 /dev/null \
             %{buildroot}%{_sysconfdir}/monotone/write-permissions
install -m 0644 /dev/null \
             %{buildroot}%{_sysconfdir}/monotone/monotonerc
install -m 0640 /dev/null \
             %{buildroot}%{_localstatedir}/lib/monotone/server.mtn

install -m 0644 -p %{SOURCE3} .

install -D -m 0644 -p contrib/Monotone.pm \
             %{buildroot}%{perl_vendorlib}/Monotone.pm


%clean
rm -f README.monotone-server
rm -rf %{buildroot}


%post
if [ $1 -eq 1 ]
then
        /sbin/install-info %{_infodir}/monotone.info %{_infodir}/dir > /dev/null 2>&1 || :
fi


%preun
if [ $1 -eq 0 ]
then
        /sbin/install-info --delete %{_infodir}/monotone.info %{_infodir}/dir > /dev/null 2>&1 || :
fi


%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING NEWS README UPGRADE
%doc _doc/*
%{_bindir}/mtn
%{_bindir}/mtnopt
%{_bindir}/mtn-cleanup
%{_infodir}/monotone.info*
%{_sysconfdir}/bash_completion.d
%{_mandir}/man1/mtn.1*
%{_mandir}/man1/mtnopt.1*
%{_mandir}/man1/mtn-cleanup.1*
%{_datadir}/monotone


%files -n perl-Monotone
%defattr(-,root,root,-)
%{perl_vendorlib}/Monotone.pm


%files server
%defattr(-,root,root,-)
%doc README.monotone-server
%{_sbindir}/monotone-server
%{_mandir}/man1/monotone-server.1*
%{_sysconfdir}/rc.d/init.d/monotone
%dir %attr(0755,monotone,monotone) %{_localstatedir}/run/monotone
%if 0%{?fedora} >= 15
# https://fedoraproject.org/wiki/Packaging:Tmpfiles.d
%config(noreplace) %{_sysconfdir}/tmpfiles.d/monotone.conf
%endif
%config(noreplace) %{_sysconfdir}/sysconfig/monotone
%dir %attr(0755,root,monotone) %{_sysconfdir}/monotone
%dir %attr(0750,root,monotone) %{_sysconfdir}/monotone/private-keys
%attr(0640,root,monotone) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{_sysconfdir}/monotone/monotonerc
%attr(0440,root,monotone) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{_sysconfdir}/monotone/passphrase.lua
%attr(0640,root,monotone) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{_sysconfdir}/monotone/read-permissions
%attr(0640,root,monotone) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{_sysconfdir}/monotone/write-permissions
%dir %attr(0770,monotone,monotone) %{_localstatedir}/lib/monotone
%attr(0660,monotone,monotone) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{_localstatedir}/lib/monotone/server.mtn


%pre server
# Add "monotone" user per http://fedoraproject.org/wiki/Packaging/UsersAndGroups
getent group monotone > /dev/null || groupadd -r monotone
getent passwd monotone > /dev/null ||
useradd -r -g monotone -r -d %{_localstatedir}/lib/monotone -s /sbin/nologin \
        -c "Monotone Netsync Server" monotone
exit 0


%post server
# Register the monotone service
/sbin/chkconfig --add monotone


%preun server
if [ $1 -eq 0 ]; then
        /sbin/service monotone stop > /dev/null 2>&1
        /sbin/chkconfig --del monotone
fi


%postun server
if [ $1 -ge 1 ]; then
        # Restart the running server: updates its db format when needed.
        /sbin/service monotone condrestart > /dev/null 2>&1 || :
fi


%changelog
* Tue Feb 28 2012 Thomas Moschny <thomas.moschny@gmx.de> - 1.0-7
- Add patch to fix building with newer pcre.

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-6
- Rebuilt for c++ ABI breakage

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Sep 26 2011 Dan Horák <dan[at]danny.cz> - 1.0-4
- fix FTBFS due a symbol conflict with boost

* Mon Jun 20 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.0-3
- Perl mass rebuild

* Thu Jun 09 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.0-2
- Perl 5.14 mass rebuild

* Sat May 14 2011 Thomas Moschny <thomas.moschny@gmx.de> - 1.0-1
- Update to 1.0.
  - Upstream ships bzip2 archives now.
  - monotone.el is no longer shipped.
  - Bash completion is installed by 'make install'.
  - Add BR on bash-completion, needed for the testsuite.
- Fix postun snippet for -server package.
- On Fedora 15 and later, use the tmpfiles.d service to create the
  /var/run/monotone directory.
- Add a patch to prevent a name clash with struct file_handle defined
  by fcntl.h in glibc 2.14.
- Add a patch fixing broken helptexts and manpage.
- Explicitly disable network access by the testsuite.
- Fix some rpmlint warnings.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.99.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Oct 31 2010 Thomas Moschny <thomas.moschny@gmx.de> - 0.99.1-1
- Update to 0.99.1.
- Remove patch already applied upstream.

* Fri Oct 29 2010 Thomas Moschny <thomas.moschny@gmx.de> - 0.99-1
- Update to 0.99.
- Remove patch already applied upstream.
- Add patch for monotone bug #100.
- Include the monotone manpage in the package.
- Specfile cleanups.

* Wed Oct 27 2010 Thomas Moschny <thomas.moschny@gmx.de> - 0.48.1-1
- Update to 0.48.1.
- Add patch from upstream to support newer sqlite.

* Mon Jun 14 2010 Thomas Moschny <thomas.moschny@gmx.de> - 0.48-1
- Update to 0.48.

* Sat May  8 2010 Thomas Moschny <thomas.moschny@gmx.de> - 0.47-3
- Add patch from upstream for a bug that prevents successful execution
  of push / pull / sync over pipes.

* Thu Apr 29 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.47-2
- Mass rebuild with perl-5.12.0

* Sun Apr 11 2010 Thomas Moschny <thomas.moschny@gmx.de> - 0.47-1
- Update to 0.47.
- Remove patch applied upstream.

* Sat Jan 23 2010 Thomas Moschny <thomas.moschny@gmx.de> - 0.46-1
- Update to 0.46.
- Remove patch applied upstream.
- Add patch from trunk for failing test.
- Fix installation of documentation: include figures in the package.
- Let tests in the testsuite run in parallel.

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.45-2
- rebuild against perl 5.10.1

* Sat Sep 12 2009 Thomas Moschny <thomas.moschny@gmx.de> - 0.45-1
- Update to 0.45.

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.44-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed May 13 2009 Thomas Moschny <thomas.moschny@gmx.de> - 0.44-1
- Update to 0.44.

* Sat Apr 25 2009 Thomas Moschny <thomas.moschny@gmx.de> - 0.43-2
- Rebuilt for new botan version.

* Fri Mar 27 2009 Thomas Moschny <thomas.moschny@gmx.de> - 0.43-1
- Update to 0.43.
- Add BRs for libraries monotone doesn't bundle anylonger.
- Drop patches applied upstream.

* Fri Feb 27 2009 Thomas Moschny <thomas.moschny@gmx.de> - 0.42-5
- Add one more netsync related patch from trunk.

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.42-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Feb  9 2009 Thomas Moschny <thomas.moschny@gmx.de> - 0.42-3
- Disable %%{_smp_mflags} in the testsuite, causes strange errors.
- Fix two issues with gcc44.
- Add patch from upstream fixing netsync printing an error message of
  the form "peer [...] IO failed in confirmed state (success)".

* Fri Jan  2 2009 Thomas Moschny <thomas.moschny@gmx.de> - 0.42-2
- Pack Monotone.pm (in a subpackage). (#450267)

* Fri Jan  2 2009 Thomas Moschny <thomas.moschny@gmx.de> - 0.42-1
- Updated for 0.42 release.

* Fri Sep 12 2008 Thomas Moschny <thomas.moschny@gmx.de> - 0.41-1
- Updated for 0.41 release.
- Added mtnopt helper.

* Mon Aug 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.40-2
- fix license tag

* Mon Apr 14 2008 Roland McGrath <roland@redhat.com> - 0.40-1
- Updated for 0.40 release.
- Tweaked trivia for packaging guidelines nits.

* Mon Feb 25 2008 Roland McGrath <roland@redhat.com> - 0.39-1
- Updated for 0.39 release.

* Sat Dec 22 2007 Roland McGrath <roland@redhat.com> - 0.38-2
- Fix monotone-server user creation. (#426607)
- Moved monotone-server database to /var/lib. (#426608)
- Use monotone@ in server key name. (#426609)

* Fri Dec 21 2007 Roland McGrath <roland@redhat.com> - 0.38-1
- Updated for 0.38 release.

* Sat Oct 27 2007 Roland McGrath <roland@redhat.com> - 0.37-3
- Updated for 0.37 release.
- Prevent destroying old passphrase file with 'service monotone genkey'.
- Put LSB standard comments in monotone.init for monotone-server subpackage.

* Tue Aug 28 2007 Roland McGrath <roland@redhat.com> - 0.36-2
- Clean up %%pre script per packaging guidelines.
- Disable ppc and ppc64 builds temporarily since make check fails. (#259161)

* Fri Aug  3 2007 Roland McGrath <roland@redhat.com> - 0.36-1
- Updated for 0.36 release.

* Fri Jul 06 2007 Florian La Roche <laroche@redhat.com> - 0.35-4
- add more requires

* Wed May 16 2007 Roland McGrath <roland@redhat.com> - 0.35-3
- Fix locale dependency in monotone-server init script. (#213893)

* Wed May  9 2007 Roland McGrath <roland@redhat.com> - 0.35-2
- Updated for 0.35 release.
- Avoid unnecessary "db migrate" in monotone-server init script. (#213893)

* Wed Apr  4 2007 Roland McGrath <roland@redhat.com> - 0.34-1
- Updated for 0.34 release.

* Thu Mar  1 2007 Roland McGrath <roland@redhat.com> - 0.33-1
- Updated for 0.33 release.
- Install monotone.bash_completion file.

* Wed Feb 28 2007 Roland McGrath <roland@redhat.com> - 0.32-1
- Updated for 0.32 release.

* Thu Dec 21 2006 Kevin Fenzi <kevin@tummy.com> - 0.31-2
- Bump and rebuild to fix upgrade path

* Sat Nov 11 2006 Roland McGrath <roland@redhat.com> - 0.31-1
- Updated for 0.31 release.

* Tue Oct 10 2006 Roland McGrath <roland@redhat.com> - 0.30-1
- Updated for 0.30 release.
- Fix service script to work around buggy init.d/functions. (#198761)

* Thu Aug  3 2006 Roland McGrath <roland@redhat.com> - 0.28-2
- Updated for 0.28 release. (#198652)
- Move server PID file into /var/run/monotone subdirectory. (#198761)

* Tue Jul 11 2006 Roland McGrath <roland@redhat.com> - 0.27-1
- Updated for 0.27 release.

* Mon May  8 2006 Roland McGrath <roland@redhat.com> - 0.26-2
- Fix service script genkey subcommand.

* Mon Apr 10 2006 Roland McGrath <roland@redhat.com> - 0.26-1
- Updated for 0.26 release.
  - Major changes; see UPGRADE doc file for details.

* Fri Jan  6 2006 Roland McGrath <roland@redhat.com> - 0.25-2
- Restore testsuite fix for nonroot owner of / in build chroot.

* Thu Jan  5 2006 Roland McGrath <roland@redhat.com> - 0.25-1
- Updated for 0.25 release.

* Sun Dec 11 2005 Roland McGrath <roland@redhat.com> - 0.24-1
- Updated for 0.24 release.

* Mon Oct  3 2005 Roland McGrath <roland@redhat.com> - 0.23-1
- Updated for 0.23 release.

* Mon Aug 22 2005 Roland McGrath <roland@redhat.com> - 0.22-4
- Updated for 0.22 release.
- Added monotone-server package.

* Sun Aug  7 2005 Roland McGrath <roland@redhat.com> - 0.21-3
- Work around non-root build user owning / in mock chroot builds.

* Wed Jul 27 2005 Roland McGrath <roland@redhat.com> - 0.21-2
- Include monotone-nav.el too.
- Add BuildRequires on cvs so the test suite can run.

* Mon Jul 18 2005 Roland McGrath <roland@redhat.com> - 0.21-1
- Updated for 0.21 release.
- Install Emacs support.

* Thu Jul  7 2005 Roland McGrath <roland@redhat.com> - 0.20-0.1
- Updated for 0.20 release.
- Added %%check section.
- Cannot use FC4 native sqlite3, need newer bundled one.

* Mon Apr 18 2005 Jeffrey C. Ollie <jcollie@lt16586.campus.dmacc.edu> - 0.18-0.4
- Modified summary so that it doesn't contain the name

* Thu Apr 14 2005 Jeffrey C. Ollie <jcollie@lt16586.campus.dmacc.edu> - 0.18-0.3
- Modified install-info commands to prevent errors in case of --excludedocs

* Wed Apr 13 2005 Jeffrey C. Ollie <jcollie@lt16586.campus.dmacc.edu> - 0.18-0.2
- Added post and postun scripts to take care of .info file
- Added parallel make flags

* Wed Apr 13 2005 Jeffrey C. Ollie <jcollie@lt16586.campus.dmacc.edu> - 0.18-0.1
- First version.
